@@ -38,6 +38,9 @@ module PowerAssert
           end
         rescue Exception => e
           warn "power_assert: [BUG] Failed to trace: #{e.class}: #{e.message}"
+          if e.respond_to?(:full_message)
+            warn e.full_message.gsub(/^/, 'power_assert:     ')
+          end
         end
       end
     end
@@ -171,7 +174,7 @@ module PowerAssert
         line = assertion_proc_or_source
       end
       @parser = Parser::DUMMY
-      @trace_call = TracePoint.new(:call, :c_call) do |tp|
+      @trace_call = TracePoint.new(:call, :c_call) do
         if PowerAssert.app_context? and Thread.current == @target_thread
           @trace_call.disable
           locs = PowerAssert.app_caller_locations
